@@ -936,6 +936,11 @@ detect_os() {
 }
 
 guess_host_type() {
+    if [ -d /etc/unifi-base-ucore ]; then
+        # Special case when installer is run from inside the ubios podman
+        echo "router"; return 0
+    fi
+
     case $OS in
     pfsense|opnsense|openwrt|asuswrt-merlin|edgeos|ddwrt|synology|overthebox|ubios)
         echo "router"
@@ -1007,7 +1012,7 @@ is_version_current() {
     */*)
         # Snapshot
         hash=${INSTALL_RELEASE#*/}
-        test "v0.0.0-$hash" = "$CURRENT_RELEASE"
+        test "0.0.0-$hash" = "$CURRENT_RELEASE"
         ;;
     *)
         test "$INSTALL_RELEASE" = "$CURRENT_RELEASE"
